@@ -21,11 +21,17 @@ Create Date: 2015-04-14 18:56:03.440329
 revision = '4ea34a59a64c'
 down_revision = '456126c6c9e9'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
     op.add_column('bay',
-                  sa.Column('discovery_url', sa.String(length=255),
+                  sa.Column('discovery_url',
+                            String(255, mysql_ndb_type=TINYTEXT),
                             nullable=True))
